@@ -30,6 +30,10 @@ class AbstractRepo(
     def get_user_by_id(self, id: int) -> Optional[TTUser]:
         """Return the user with ``id``, or None."""
 
+    @abstractmethod
+    def one_user_by_id(self, id: int) -> TTUser:
+        """Return the user with ``id``, or raise."""
+
     @abstractmethod
     def get_user_by_email(self, email: str) -> Optional[TTUser]:
         """Return a user with ``email``, or None."""
