@@ -3,6 +3,10 @@
 from datetime import datetime
 from typing import Generic, TypeVar
 
+from kerno.state import Rezulto
+
+from pluserable.data.models import ActivationBase
+
 TActivation = TypeVar("TActivation")
 TGroup = TypeVar("TGroup")
 TTUser = TypeVar("TTUser")
@@ -11,6 +15,7 @@ TTUser = TypeVar("TTUser")
 class TUser(Generic[TActivation, TGroup]):
     """Typing stub for a concrete User class."""
 
+    id: int
     email: str
     password: str
     salt: str
@@ -21,3 +26,15 @@ class TUser(Generic[TActivation, TGroup]):
     def check_password(self, password: str) -> bool:
         """Check the ``password`` and return a boolean."""
         ...
+
+
+class UserRezulto(Rezulto):
+    """Typing stub for a Rezulto object that includes an authenticated user."""
+
+    user: TUser
+
+
+class ActivationRezulto(UserRezulto):
+    """Typing stub for a Rezulto with ``user`` and ``activation``."""
+
+    activation: ActivationBase
